pub struct DeleteDataCatalogFluentBuilder { /* private fields */ }Expand description
Fluent builder constructing a request to DeleteDataCatalog.
Deletes a data catalog.
Implementations
Sourceimpl DeleteDataCatalogFluentBuilder
impl DeleteDataCatalogFluentBuilder
Sourcepub fn as_input(&self) -> &DeleteDataCatalogInputBuilder
pub fn as_input(&self) -> &DeleteDataCatalogInputBuilder
Access the DeleteDataCatalog as a reference.
Sourcepub async fn send(
self,
) -> Result<DeleteDataCatalogOutput, SdkError<DeleteDataCatalogError, HttpResponse>>
pub async fn send( self, ) -> Result<DeleteDataCatalogOutput, SdkError<DeleteDataCatalogError, HttpResponse>>
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
Sourcepub fn customize(
self,
) -> CustomizableOperation<DeleteDataCatalogOutput, DeleteDataCatalogError, Self>
pub fn customize( self, ) -> CustomizableOperation<DeleteDataCatalogOutput, DeleteDataCatalogError, Self>
Consumes this builder, creating a customizable operation that can be modified before being sent.
Sourcepub fn delete_catalog_only(self, input: bool) -> Self
pub fn delete_catalog_only(self, input: bool) -> Self
Deletes the Athena Data Catalog. You can only use this with the FEDERATED catalogs. You usually perform this before registering the connector with Glue Data Catalog. After deletion, you will have to manage the Glue Connection and Lambda function.
Sourcepub fn set_delete_catalog_only(self, input: Option<bool>) -> Self
pub fn set_delete_catalog_only(self, input: Option<bool>) -> Self
Deletes the Athena Data Catalog. You can only use this with the FEDERATED catalogs. You usually perform this before registering the connector with Glue Data Catalog. After deletion, you will have to manage the Glue Connection and Lambda function.
Sourcepub fn get_delete_catalog_only(&self) -> &Option<bool>
pub fn get_delete_catalog_only(&self) -> &Option<bool>
Deletes the Athena Data Catalog. You can only use this with the FEDERATED catalogs. You usually perform this before registering the connector with Glue Data Catalog. After deletion, you will have to manage the Glue Connection and Lambda function.