DeleteDataCatalogInputBuilder

Struct DeleteDataCatalogInputBuilder 

#[non_exhaustive]
pub struct DeleteDataCatalogInputBuilder { /* private fields */ }
A builder for DeleteDataCatalogInput.

Implementations

Source

impl DeleteDataCatalogInputBuilder

pub fn name(self, input: impl Into<String>) -> Self

The name of the data catalog to delete.

This field is required.
pub fn set_name(self, input: Option<String>) -> Self

The name of the data catalog to delete.

pub fn get_name(&self) -> &Option<String>

The name of the data catalog to delete.

pub fn delete_catalog_only(self, input: bool) -> Self

Deletes the Athena Data Catalog. You can only use this with the FEDERATED catalogs. You usually perform this before registering the connector with Glue Data Catalog. After deletion, you will have to manage the Glue Connection and Lambda function.

pub fn set_delete_catalog_only(self, input: Option<bool>) -> Self

Deletes the Athena Data Catalog. You can only use this with the FEDERATED catalogs. You usually perform this before registering the connector with Glue Data Catalog. After deletion, you will have to manage the Glue Connection and Lambda function.

pub fn get_delete_catalog_only(&self) -> &Option<bool>

Deletes the Athena Data Catalog. You can only use this with the FEDERATED catalogs. You usually perform this before registering the connector with Glue Data Catalog. After deletion, you will have to manage the Glue Connection and Lambda function.

pub fn build(self) -> Result<DeleteDataCatalogInput, BuildError>

Consumes the builder and constructs a DeleteDataCatalogInput.

Source

impl DeleteDataCatalogInputBuilder

pub async fn send_with( self, client: &Client, ) -> Result<DeleteDataCatalogOutput, SdkError<DeleteDataCatalogError, HttpResponse>>

Sends a request with this input using the given client.