#[non_exhaustive]pub struct DeleteDataCatalogOutputBuilder { /* private fields */ }Expand description
A builder for DeleteDataCatalogOutput.
Implementations
Sourceimpl DeleteDataCatalogOutputBuilder
impl DeleteDataCatalogOutputBuilder
Sourcepub fn data_catalog(self, input: DataCatalog) -> Self
pub fn data_catalog(self, input: DataCatalog) -> Self
Contains information about a data catalog in an Amazon Web Services account.
In the Athena console, data catalogs are listed as "data sources" on the Data sources page under the Data source name column.
Sourcepub fn set_data_catalog(self, input: Option<DataCatalog>) -> Self
pub fn set_data_catalog(self, input: Option<DataCatalog>) -> Self
Contains information about a data catalog in an Amazon Web Services account.
In the Athena console, data catalogs are listed as "data sources" on the Data sources page under the Data source name column.
Sourcepub fn get_data_catalog(&self) -> &Option<DataCatalog>
pub fn get_data_catalog(&self) -> &Option<DataCatalog>
Contains information about a data catalog in an Amazon Web Services account.
In the Athena console, data catalogs are listed as "data sources" on the Data sources page under the Data source name column.
Sourcepub fn build(self) -> DeleteDataCatalogOutput
pub fn build(self) -> DeleteDataCatalogOutput
Consumes the builder and constructs a DeleteDataCatalogOutput.