#[non_exhaustive]pub struct DeleteDataCatalogInputBuilder { /* private fields */ }Expand description
A builder for DeleteDataCatalogInput.
Implementations
Sourceimpl DeleteDataCatalogInputBuilder
impl DeleteDataCatalogInputBuilder
Sourcepub fn name(self, input: impl Into<String>) -> Self
pub fn name(self, input: impl Into<String>) -> Self
The name of the data catalog to delete.
This field is required.Sourcepub fn delete_catalog_only(self, input: bool) -> Self
pub fn delete_catalog_only(self, input: bool) -> Self
Deletes the Athena Data Catalog. You can only use this with the FEDERATED catalogs. You usually perform this before registering the connector with Glue Data Catalog. After deletion, you will have to manage the Glue Connection and Lambda function.
Sourcepub fn set_delete_catalog_only(self, input: Option<bool>) -> Self
pub fn set_delete_catalog_only(self, input: Option<bool>) -> Self
Deletes the Athena Data Catalog. You can only use this with the FEDERATED catalogs. You usually perform this before registering the connector with Glue Data Catalog. After deletion, you will have to manage the Glue Connection and Lambda function.
Sourcepub fn get_delete_catalog_only(&self) -> &Option<bool>
pub fn get_delete_catalog_only(&self) -> &Option<bool>
Deletes the Athena Data Catalog. You can only use this with the FEDERATED catalogs. You usually perform this before registering the connector with Glue Data Catalog. After deletion, you will have to manage the Glue Connection and Lambda function.
Sourcepub fn build(self) -> Result<DeleteDataCatalogInput, BuildError>
pub fn build(self) -> Result<DeleteDataCatalogInput, BuildError>
Consumes the builder and constructs a DeleteDataCatalogInput.
Sourceimpl DeleteDataCatalogInputBuilder
impl DeleteDataCatalogInputBuilder
Sourcepub async fn send_with(
self,
client: &Client,
) -> Result<DeleteDataCatalogOutput, SdkError<DeleteDataCatalogError, HttpResponse>>
pub async fn send_with( self, client: &Client, ) -> Result<DeleteDataCatalogOutput, SdkError<DeleteDataCatalogError, HttpResponse>>
Sends a request with this input using the given client.